@@ -17,7 +17,7 @@ CONFIG = {
         "LOCAL": {
             "TEST_URL": "https://rec-stg.shinsegae.ai/v1",
             "MLOPS_REC_URL": "https://rec-stg.shinsegae.ai/v1",
-            "MLOPS_DATA_URL": "https://data-stg.shinsegae.ai/v1",
+            "MLOPS_DATA_URL": "http://internal-data-stg-v1.shinsegae.ai",
         },
         "MLOPS": {
             "TEST_URL": "https://rec-stg.shinsegae.ai/v1",
@@ -29,7 +29,7 @@ CONFIG = {
         "LOCAL": {
             "TEST_URL": "https://rec.shinsegae.ai/v1",
             "MLOPS_REC_URL": "https://rec.shinsegae.ai/v1",
-            "MLOPS_DATA_URL": "https://data.shinsegae.ai/v1",
+            "MLOPS_DATA_URL": "http://internal-data-prd-v1.shinsegae.ai",
         },
         "MLOPS": {
             "TEST_URL": "https://rec.shinsegae.ai/v1",
